nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Fifowr

Struct Fifowr 

#[repr(transparent)]
pub struct Fifowr(pub u32);
FIFO write data.

Tuple Fields

0: u32

Implementations

Source

impl Fifowr

pub const fn txdata(&self) -> u16

Transmit data to the FIFO.

pub const fn set_txdata(&mut self, val: u16)

Transmit data to the FIFO.

pub const fn txssel0_n(&self) -> Txssel0N

Transmit slave select. This field asserts SSEL0 in master mode. The output on the pin is active LOW by default.

pub const fn set_txssel0_n(&mut self, val: Txssel0N)

Transmit slave select. This field asserts SSEL0 in master mode. The output on the pin is active LOW by default.

pub const fn txssel1_n(&self) -> Txssel1N

Transmit slave select. This field asserts SSEL1 in master mode. The output on the pin is active LOW by default.

pub const fn set_txssel1_n(&mut self, val: Txssel1N)

Transmit slave select. This field asserts SSEL1 in master mode. The output on the pin is active LOW by default.

pub const fn txssel2_n(&self) -> Txssel2N

Transmit slave select. This field asserts SSEL2 in master mode. The output on the pin is active LOW by default.

pub const fn set_txssel2_n(&mut self, val: Txssel2N)

Transmit slave select. This field asserts SSEL2 in master mode. The output on the pin is active LOW by default.

pub const fn txssel3_n(&self) -> Txssel3N

Transmit slave select. This field asserts SSEL3 in master mode. The output on the pin is active LOW by default.

pub const fn set_txssel3_n(&mut self, val: Txssel3N)

Transmit slave select. This field asserts SSEL3 in master mode. The output on the pin is active LOW by default.

pub const fn eot(&self) -> bool

End of transfer. The asserted SSEL will be deasserted at the end of a transfer and remain so far at least the time specified by the Transfer_delay value in the DLY register.

pub const fn set_eot(&mut self, val: bool)

End of transfer. The asserted SSEL will be deasserted at the end of a transfer and remain so far at least the time specified by the Transfer_delay value in the DLY register.

pub const fn eof(&self) -> bool

End of frame. Between frames, a delay may be inserted, as defined by the Frame_delay value in the DLY register. The end of a frame may not be particularly meaningful if the Frame_delay value = 0. This control can be used as part of the support for frame lengths greater than 16 bits.

pub const fn set_eof(&mut self, val: bool)

End of frame. Between frames, a delay may be inserted, as defined by the Frame_delay value in the DLY register. The end of a frame may not be particularly meaningful if the Frame_delay value = 0. This control can be used as part of the support for frame lengths greater than 16 bits.

pub const fn rxignore(&self) -> Rxignore

Receive Ignore. This allows data to be transmitted using the SPI without the need to read unneeded data from the receiver. Setting this bit simplifies the transmit process and can be used with the DMA.

pub const fn set_rxignore(&mut self, val: Rxignore)

Receive Ignore. This allows data to be transmitted using the SPI without the need to read unneeded data from the receiver. Setting this bit simplifies the transmit process and can be used with the DMA.

pub const fn txignore(&self) -> Txignore

Transmit Ignore

pub const fn set_txignore(&mut self, val: Txignore)

Transmit Ignore

pub const fn len(&self) -> u8

Data Length. Specifies the data length from 4 to 16 bits. Note that transfer lengths greater than 16 bits are supported by implementing multiple sequential transmits. 0x0-2 = Reserved. 0x3 = Data transfer is 4 bits in length. 0x4 = Data transfer is 5 bits in length. 0xF = Data transfer is 16 bits in length.

pub const fn set_len(&mut self, val: u8)

Data Length. Specifies the data length from 4 to 16 bits. Note that transfer lengths greater than 16 bits are supported by implementing multiple sequential transmits. 0x0-2 = Reserved. 0x3 = Data transfer is 4 bits in length. 0x4 = Data transfer is 5 bits in length. 0xF = Data transfer is 16 bits in length.