nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Intenset

Struct Intenset 

#[repr(transparent)]
pub struct Intenset(pub u32);
SPI Interrupt Enable read and Set. A complete value may be read from this register. Writing a 1 to any implemented bit position causes that bit to be set.

Tuple Fields

0: u32

Implementations

Source

impl Intenset

pub const fn ssaen(&self) -> bool

Slave select assert interrupt enable. Determines whether an interrupt occurs when the Slave Select is asserted.

pub const fn set_ssaen(&mut self, val: bool)

Slave select assert interrupt enable. Determines whether an interrupt occurs when the Slave Select is asserted.

pub const fn ssden(&self) -> bool

Slave select deassert interrupt enable. Determines whether an interrupt occurs when the Slave Select is deasserted.

pub const fn set_ssden(&mut self, val: bool)

Slave select deassert interrupt enable. Determines whether an interrupt occurs when the Slave Select is deasserted.

pub const fn mstidleen(&self) -> bool

Master idle interrupt enable.

pub const fn set_mstidleen(&mut self, val: bool)

Master idle interrupt enable.